VmPage

Struct VmPage 

pub struct VmPage {
    pub index: usize,
    pub vm: usize,
    pub addr: usize,
    pub segment: usize,
    pub state: Mutex<PageState>,
    pub unk1: u8,
}
Implementation of vm_page structure.

Fields

index: usizevm: usizeaddr: usizesegment: usizestate: Mutex<PageState>

This MUST be locked after free queue.

unk1: u8

Implementations

Source

impl VmPage

pub unsafe fn fill_with_zeros(&self)

See pagezero on the Orbis for a reference.

Safety

The caller must have exclusive access to this page and no any references to the data within this page.

Reference offsets
VersionOffset
PS4 11.000x2DDD70
Source

impl VmPage

pub const FREE_ORDER: usize = 13

pub fn new( index: usize, vm: usize, pool: usize, addr: usize, segment: usize, ) -> Self